@@ -6,7 +6,7 @@
 //!
 //! ```toml
 //! [dependencies]
-//! sql-builder = "0.4"
+//! sql-builder = "0.5"
 //! ```
 //!
 //! Next, add this to your crate:
@@ -584,7 +584,7 @@ impl SqlBuilder {
     /// extern crate sql_builder;
     ///
     /// # use std::error::Error;
-    /// use sql_builder::{SqlBuilder, quote};
+    /// use sql_builder::SqlBuilder;
     ///
     /// # fn main() -> Result<(), Box<dyn Error>> {
     /// let sql = SqlBuilder::select_from("books")
@@ -611,7 +611,7 @@ impl SqlBuilder {
     /// extern crate sql_builder;
     ///
     /// # use std::error::Error;
-    /// use sql_builder::{SqlBuilder, quote};
+    /// use sql_builder::SqlBuilder;
     ///
     /// # fn main() -> Result<(), Box<dyn Error>> {
     /// let sql = SqlBuilder::select_from("books")
@@ -639,7 +639,7 @@ impl SqlBuilder {
     /// extern crate sql_builder;
     ///
     /// # use std::error::Error;
-    /// use sql_builder::{SqlBuilder, quote};
+    /// use sql_builder::SqlBuilder;
     ///
     /// # fn main() -> Result<(), Box<dyn Error>> {
     /// let sql = SqlBuilder::select_from("books")
@@ -728,7 +728,7 @@ impl SqlBuilder {
     /// extern crate sql_builder;
     ///
     /// # use std::error::Error;
-    /// use sql_builder::{SqlBuilder, quote};
+    /// use sql_builder::SqlBuilder;
     ///
     /// # fn main() -> Result<(), Box<dyn Error>> {
     /// let sql = SqlBuilder::select_from("books")
@@ -760,7 +760,7 @@ impl SqlBuilder {
     /// extern crate sql_builder;
     ///
     /// # use std::error::Error;
-    /// use sql_builder::{SqlBuilder, quote};
+    /// use sql_builder::SqlBuilder;
     ///
     /// # fn main() -> Result<(), Box<dyn Error>> {
     /// let sql = SqlBuilder::select_from("books")
@@ -792,7 +792,7 @@ impl SqlBuilder {
     /// extern crate sql_builder;
     ///
     /// # use std::error::Error;
-    /// use sql_builder::{SqlBuilder, quote};
+    /// use sql_builder::SqlBuilder;
     ///
     /// # fn main() -> Result<(), Box<dyn Error>> {
     /// let sql = SqlBuilder::select_from("books")
@@ -824,7 +824,7 @@ impl SqlBuilder {
     /// extern crate sql_builder;
     ///
     /// # use std::error::Error;
-    /// use sql_builder::{SqlBuilder, quote};
+    /// use sql_builder::SqlBuilder;
     ///
     /// # fn main() -> Result<(), Box<dyn Error>> {
     /// let sql = SqlBuilder::select_from("books")
@@ -972,7 +972,7 @@ impl SqlBuilder {
     /// extern crate sql_builder;
     ///
     /// # use std::error::Error;
-    /// use sql_builder::{SqlBuilder, quote};
+    /// use sql_builder::SqlBuilder;
     ///
     /// # fn main() -> Result<(), Box<dyn Error>> {
     /// let sql = SqlBuilder::select_from("books")
@@ -1068,18 +1068,19 @@ impl SqlBuilder {
     /// extern crate sql_builder;
     ///
     /// # use std::error::Error;
-    /// use sql_builder::{SqlBuilder, quote};
+    /// use sql_builder::SqlBuilder;
     ///
     /// # fn main() -> Result<(), Box<dyn Error>> {
     /// let sql = SqlBuilder::select_from("books")
     ///     .field("title")
     ///     .field("price")
+    ///     .and_where_lt("price", 100.to_string())
     ///     .or_where_gt("price", 300.to_string())
     ///     .sql()?;
     ///
-    /// assert_eq!("SELECT title, price FROM books WHERE price > 300;", &sql);
-    /// // add                                           ^^^^^   ^^^
-    /// // here                                          field  value
+    /// assert_eq!("SELECT title, price FROM books WHERE price < 100 OR price > 300;", &sql);
+    /// // add                                                          ^^^^^   ^^^
+    /// // here                                                         field  value
     /// # Ok(())
     /// # }
     /// ```
@@ -1100,18 +1101,19 @@ impl SqlBuilder {
     /// extern crate sql_builder;
     ///
     /// # use std::error::Error;
-    /// use sql_builder::{SqlBuilder, quote};
+    /// use sql_builder::SqlBuilder;
     ///
     /// # fn main() -> Result<(), Box<dyn Error>> {
     /// let sql = SqlBuilder::select_from("books")
     ///     .field("title")
     ///     .field("price")
+    ///     .or_where_lt("price", 100.to_string())
     ///     .or_where_ge("price", 300.to_string())
     ///     .sql()?;
     ///
-    /// assert_eq!("SELECT title, price FROM books WHERE price >= 300;", &sql);
-    /// // add                                           ^^^^^    ^^^
-    /// // here                                          field   value
+    /// assert_eq!("SELECT title, price FROM books WHERE price < 100 OR price >= 300;", &sql);
+    /// // add                                           ^^^^^   ^^^    ^^^^^    ^^^
+    /// // here                                          field  value   field   value
     /// # Ok(())
     /// # }
     /// ```
@@ -1132,18 +1134,19 @@ impl SqlBuilder {
     /// extern crate sql_builder;
     ///
     /// # use std::error::Error;
-    /// use sql_builder::{SqlBuilder, quote};
+    /// use sql_builder::SqlBuilder;
     ///
     /// # fn main() -> Result<(), Box<dyn Error>> {
     /// let sql = SqlBuilder::select_from("books")
     ///     .field("title")
     ///     .field("price")
+    ///     .and_where_lt("price", 100.to_string())
     ///     .or_where_lt("price", 300.to_string())
     ///     .sql()?;
     ///
-    /// assert_eq!("SELECT title, price FROM books WHERE price < 300;", &sql);
-    /// // add                                           ^^^^^   ^^^
-    /// // here                                          field  value
+    /// assert_eq!("SELECT title, price FROM books WHERE price < 100 OR price < 300;", &sql);
+    /// // add                                                          ^^^^^   ^^^
+    /// // here                                                         field  value
     /// # Ok(())
     /// # }
     /// ```
@@ -1164,18 +1167,19 @@ impl SqlBuilder {
     /// extern crate sql_builder;
     ///
     /// # use std::error::Error;
-    /// use sql_builder::{SqlBuilder, quote};
+    /// use sql_builder::SqlBuilder;
     ///
     /// # fn main() -> Result<(), Box<dyn Error>> {
     /// let sql = SqlBuilder::select_from("books")
     ///     .field("title")
     ///     .field("price")
+    ///     .or_where_lt("price", 100.to_string())
     ///     .or_where_le("price", 300.to_string())
     ///     .sql()?;
     ///
-    /// assert_eq!("SELECT title, price FROM books WHERE price <= 300;", &sql);
-    /// // add                                           ^^^^^    ^^^
-    /// // here                                          field   value
+    /// assert_eq!("SELECT title, price FROM books WHERE price < 100 OR price <= 300;", &sql);
+    /// // add                                           ^^^^^   ^^^    ^^^^^    ^^^
+    /// // here                                          field  value   field   value
     /// # Ok(())
     /// # }
     /// ```
@@ -1996,7 +2000,7 @@ mod tests {
     fn test_select_price_for_harry_potter_and_phil_stone() -> Result<(), Box<dyn Error>> {
         let sql = SqlBuilder::select_from("books")
             .field("price")
-            .and_where_eq("title", &quote("Harry Potter and the Philosopher's Stone"))
+            .and_where_eq("title", quote("Harry Potter and the Philosopher's Stone"))
             .sql()?;
 
         assert_eq!(
@@ -2011,7 +2015,7 @@ mod tests {
     fn test_select_price_not_for_harry_potter_and_phil_stone() -> Result<(), Box<dyn Error>> {
         let sql = SqlBuilder::select_from("books")
             .field("price")
-            .and_where_ne("title", &quote("Harry Potter and the Philosopher's Stone"))
+            .and_where_ne("title", quote("Harry Potter and the Philosopher's Stone"))
             .sql()?;
 
         assert_eq!(
@@ -2046,7 +2050,7 @@ mod tests {
             .field("price")
             .and_where("price < 2")
             .or_where("price > 1000")
-            .or_where_eq("title", &quote("Harry Potter and the Philosopher's Stone"))
+            .or_where_eq("title", quote("Harry Potter and the Philosopher's Stone"))
             .or_where_ne("price", 100)
             .or_where_like("title", "Alice's")
             .or_where_not_like("title", "% the %")
